many2oneeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# many2oneeditor

class `camelot.view.controls.editors.many2oneeditor.` `Many2OneEditor`(admin=None, parent=None, editable=True, field_name='manytoone', **kwargs)

  Widget for editing many 2 one relations

  `get_value`()

    Returns: | a function that returns the selected entity or ValueLoading

    or None

  `search_completions`(*args, **kwargs)

    Search for object that match text, to fill the list of completions

    Returns: | a list of tuples of (object_representation, object_getter)

  `set_instance_representation`(representation_and_propagate)

    Update the gui

  `set_value`(value)

    Parameters: | value – either ValueLoading, or a function that returns None

    or the entity to be shown in the editor

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus